{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block content %}
<div class="row mb-3">
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">Address Family</h5>
            <div class="card-body">
                <table class="table table-hover attr-table">
                    <tr>
                        <th scope="row">Name</th>
                        <td>
                            <a href="{{object.name.get_absolute_url}}">{{ object.name }}</a>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">VPNV4 Community</th>
                        <td>
                            {{ object.vpnv4_community }}
                        </td>
                        {% if object.vpnv4_address_family %}
                        <th scope="row">Active</th>
                        {% else %}
                        <th scope="row">Inactive</th>
                        {% endif %}
                    </tr>
                    <tr>
                        <th scope="row">VPNV6 Community</th>
                        <td>
                            {{ object.vpnv6_community }}
                        </td>
                        {% if object.vpnv6_address_family %}
                        <th scope="row">Active</th>
                        {% else %}
                        <th scope="row">Inactive</th>
                        {% endif %}
                    </tr>
                </table>
            </div>
        </div>
        {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
        {% include 'inc/panels/tags.html' %}
        {% include 'inc/panels/comments.html' %}
    </div>
</div>
{% endblock content %}
